﻿using System.Drawing;

namespace DessinObjets
{
    /// <summary>
    /// La classe Rect encapsule un rectangle avec son épaisseur, la couleur de son bord et un texte
    /// </summary>
    public class Rect
    {
        #region Propriétés
        public int Epaisseur
        {
            get
            {
                return epaisseur;
            }
            set
            {
                epaisseur = value;
            }
        }
        public Color Couleur
        {
            get
            {
                return couleur;
            }
            set
            {
                couleur = value;
            }
        }
        public Point Centre
        {
            get
            {
                return new Point(rect.Left + rect.Width / 2, rect.Top + rect.Height / 2);
            }
        }
        public string Texte
        {
            get { return texte; }
            set { texte = value; }
        }
        #endregion
        #region Membres privés
        private Rectangle rect;
        private Color couleur;
        private int epaisseur;
        private string texte;
        #endregion
        /// <summary>
        /// Construit un objet Rect
        /// </summary>
        /// <param name="r">rectangle de base</param>
        /// <param name="c">couleur initiale</param>
        /// <param name="e">épaisseur initiale</param>
        public Rect(Rectangle r, Color c, int e)
        {
            rect = r;
            couleur = c;
            epaisseur = e;
        }
        /// <summary>
        /// Dessine le rect
        /// </summary>
        /// <param name="g">Zone de dessin</param>
        public void Dessine(Graphics g)
        {
            Pen p = new Pen(couleur, epaisseur);
            g.DrawRectangle(p, rect);
            Font police = new Font("Arial", 12);
            g.DrawString(texte, police, Brushes.Black, Centre);
        }
        /// <summary>
        /// Teste la présence d'un point
        /// </summary>
        /// <param name="pt">Point à tester</param>
        /// <returns>true si la forme contient le point</returns>
        public bool Contains(Point pt)
        {
            return rect.Contains(pt);
        }
    }
}
